#######################################################################
# Database definitions
#######################################################################

# Using Mysql 3.23.2 or later (required for NULLs allowed in indexed fields)

# NOTE: We allow nulls in the 3 "triplet" fields for manual white/black listing.  A null indicates that that field 
#   should not be considered when looking for a match.  Automatic entries will always have all three populated.
# Note: Since we index the triplet fields, and allow them to be null, this requires at least Mysql 3.23.2 and MYISAM
#   tables.
CREATE TABLE `greylisting_data`     # Stores settings for each [relay, to, from] triplet
(
        `id`              bigint          NOT NULL        auto_increment, # unique triplet id
        `relay_ip`        char(40),                                       # sending relay in IPv4/v6 ascii dotted quad notation
        `mail_from`       varchar(255),                                   # ascii address of sender
        `rcpt_to`         varchar(255),                                   # the recipient address.
        `block_expires`   datetime        NOT NULL,                       # the time that an initial block will/did expire
        `record_expires`  datetime        NOT NULL,                       # the date after which this record is ignored

        `blocked_count`   bigint          NOT NULL default '0',           # num of blocked attempts to deliver
        `passed_count`    bigint          NOT NULL default '0',           # num of passed attempts we have allowed
        `aborted_count`   bigint          NOT NULL default '0',           # num of attempts we have passed, but were later aborted
        `origin_type`     enum("MANUAL","AUTO") NOT NULL,                 # indicates the origin of this record (auto, or manual)
        `create_time`     datetime        NOT NULL,                       # timestamp of creation time of this record
        `last_update`     timestamp       DEFAULT CURRENT_TIMESTAMP
                                          ON UPDATE CURRENT_TIMESTAMP,    # timestamp of last change to this record (automatic)
        `comment`         varchar(255)    NOT NULL,                       # for comments

        PRIMARY KEY (`id`),
        KEY `relay_ip` (`relay_ip`),
        KEY `mail_from` (`mail_from`(20)),                                # To keep the index size down, only index first 20 chars
        KEY `rcpt_to` (`rcpt_to`(20))
);

# Example wildcard whitelist + blacklist for subnets
#INSERT INTO `greylisting_data` VALUES (0,"127.0.0.1",NULL,NULL,"0000-00-00 00:00:00","9999-12-31 23:59:59",0,0,0,"MANUAL",NOW(),NOW(),'whitelist');
#INSERT INTO `greylisting_data` VALUES (0,"192.168.",NULL,NULL,"9999-12-31 23:59:59","9999-12-31 23:59:59",0,0,0,"MANUAL",NOW(),NOW(),'blacklist');

# Example wildcard whitelist + blacklist entry for a recieved domain or subdomain
#INSERT INTO `greylisting_data` VALUES (0,NULL,NULL,"domain.com","0000-00-00 00:00:00","9999-12-31 23:59:59",0,0,0,"MANUAL",NOW(),NOW(),'whitelist');
#INSERT INTO `greylisting_data` VALUES (0,NULL,NULL,"sub.domain.com","9999-12-31 23:59:59","9999-12-31 23:59:59",0,0,0,"MANUAL",NOW(),NOW(),'blacklist');
